@@ -1,7 +1,12 @@
-# set MKS Korn shell environment variables for MS Visual Studio 2015
+# set MKS Korn shell environment variables for MS Visual Studio 2019
+# Revision history
+#            2022-09-04: changed "egrep" to "grep -E"
+#            2021-09-26: revised to use Visual Studio 2019
+#            2020-05-08: revised to prevent MKS Toolkit from prepending
+#                        UTF-8 signature
+#            2016-05-28: initial version
 #
-# !!! modified version !!!
-# Copyright (C) 2016, 2020 Free Software Foundation, Inc
+# Copyright (C) 2016, 2020, 2022 Free Software Foundation, Inc
 
 # Microsoft Visual Studio requires that several environment variables
 # include many directories if a build is to be done from the command
@@ -38,10 +43,10 @@
 #
 # 
 # This program was written by Jeff Conrad (jeff_conrad@msn.com), and
-# tested with the MKS Toolkit version 10.0 and Microsoft Visual Studio
-# 2015 on Windows 10 Professional.
+# tested with the MKS Toolkit version 10.2 and Microsoft Visual Studio
+# 2019 on Windows 10 Professional.
 
-# variables needed for Visual Studio 2015
+# variables needed for Visual Studio 2019
 envvars='PATH=|INCLUDE=|LIB=|PATH='
 
 # batch file: this value is installation and version dependent--adjust
@@ -50,11 +55,11 @@ envvars='PATH=|INCLUDE=|LIB=|PATH='
 
 case $1 in
 x86|32|32bit|32-bit)
-    vsbatfile="C:\Program Files (x86)\Microsoft Visual Studio 14.0\Common7\Tools\VsDevCmd.bat"
+    vsbatfile="C:\Program Files (x86)\Microsoft Visual Studio\2019\Community\VC\Auxiliary\Build\vcvars32.bat"
     vsarch=
     ;;
-*)
-    vsbatfile="C:\Program Files (x86)\Microsoft Visual Studio 14.0\VC\vcvarsall.bat"
+amd64|64|64bit|64-bit|*)
+    vsbatfile="C:\Program Files (x86)\Microsoft Visual Studio\2019\Community\VC\Auxiliary\Build\vcvars64.bat"
     vsarch=amd64
     ;;
 esac
@@ -78,10 +83,10 @@ then
 else
     OPATH="$PATH"
 
-    # keep UTF-8 signature from getting prepended with MKS Toolkit
+    # keep UTF-8 signature from getting prepended
     export TK_HEREDOC_FORMAT=ascii
     # turn off echoing with /q
-    eval `$ComSpec /q  <<END | egrep "$envvars"
+    eval `$ComSpec /q  <<END | grep -E "$envvars"
 rem set the prompt to a space
 prompt \\$s
 call "$vsbatfile" $vsarch
